@@ -235,7 +235,12 @@ gtr_view_set_language (GtrView *view,
   GList *langs = (GList *)gspell_language_get_available ();
   gchar **lang_parts = NULL;
   gboolean found = FALSE;
-  gchar *def_lang = get_default_lang (lang);
+  gchar *def_lang;
+
+  if (!lang || *lang == '\0')
+    return;
+
+  def_lang = get_default_lang (lang);
 
   while (langs)
     {
@@ -330,12 +335,23 @@ gtr_view_enable_visible_whitespace (GtrView * view, gboolean enable)
 {
   GtkSourceView *source;
   GtkSourceSpaceDrawer *drawer;
+  GtkSourceBuffer *buffer;
+  GtkSourceLanguageManager *manager;
+  GtkSourceLanguage *lang;
 
   g_return_if_fail (GTR_IS_VIEW (view));
 
+  manager = gtk_source_language_manager_get_default ();
+  lang = gtk_source_language_manager_guess_language (manager, "file.xml", NULL);
+
   source = GTK_SOURCE_VIEW (view);
   drawer = gtk_source_view_get_space_drawer (source);
   gtk_source_space_drawer_set_enable_matrix (drawer, TRUE);
+  buffer = GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
+  gtk_source_buffer_set_implicit_trailing_newline (buffer, FALSE);
+  gtk_source_buffer_set_language (buffer, lang);
+
+  gtk_source_buffer_set_highlight_syntax (buffer, TRUE);
 
   if (enable)
     gtk_source_space_drawer_set_types_for_locations (drawer,
